@@ -343,6 +343,54 @@ void AbstractSPRequest::setAuthType(const char* authtype)
 
 }
 
+const char* AbstractSPRequest::getCookie(const char* name) const
+{
+    pair<bool, bool> sameSiteFallback = pair<bool, bool>(false, false);
+    const PropertySet* props = getApplication().getPropertySet("Sessions");
+    if (props) {
+        sameSiteFallback = props->getBool("sameSiteFallback");
+    }
+    return HTTPRequest::getCookie(name, sameSiteFallback.first && sameSiteFallback.second);
+}
+
+void AbstractSPRequest::setCookie(const char* name, const char* value, time_t expires, samesite_t sameSite)
+{
+    static const char* defProps="; path=/; HttpOnly";
+    static const char* sslProps="; path=/; secure; HttpOnly";
+
+    const char* cookieProps = defProps;
+    pair<bool,bool> sameSiteFallback = pair<bool,bool>(false, false);
+
+    const PropertySet* props = getApplication().getPropertySet("Sessions");
+    if (props) {
+        if (sameSite == SAMESITE_NONE) {
+            sameSiteFallback = props->getBool("sameSiteFallback");
+        }
+
+        pair<bool, const char*> p = props->getString("cookieProps");
+        if (p.first) {
+            if (!strcmp(p.second, "https"))
+                cookieProps = sslProps;
+            else if (strcmp(p.second, "http"))
+                cookieProps = p.second;
+        }
+    }
+
+    if (cookieProps) {
+        string decoratedValue(value ? value : "");
+        if (!value) {
+            decoratedValue += "; expires=Mon, 01 Jan 2001 00:00:00 GMT";
+        }
+        decoratedValue += cookieProps;
+        HTTPResponse::setCookie(name, decoratedValue.c_str(), expires, sameSite,
+            sameSiteFallback.first && sameSiteFallback.second);
+    }
+    else {
+        HTTPResponse::setCookie(name, value, expires, sameSite,
+            sameSiteFallback.first && sameSiteFallback.second);
+    }
+}
+
 void AbstractSPRequest::log(SPLogLevel level, const std::string& msg) const
 {
     reinterpret_cast<Category*>(m_log)->log(
