@@ -132,6 +132,7 @@ namespace shibsp {
         vector<string> m_bindings;
         map< string,boost::shared_ptr<MessageEncoder> > m_encoders;
         auto_ptr_char m_protocol;
+        bool m_notifyWithoutSession;
 #endif
     };
 
@@ -157,6 +158,11 @@ SAML2Logout::SAML2Logout(const DOMElement* e, const char* appId, bool deprecatio
     m_preserve.push_back("entityID");
     m_preserve.push_back("RelayState");
 
+    pair<bool, bool> flag = getBool("notifyWithoutSession", shibspconstants::ASCII_SHIBSPCONFIG_NS);
+    if (!flag.first)
+        flag = getBool("notifyWithoutSession");
+    m_notifyWithoutSession = flag.first && flag.second;
+
     if (SPConfig::getConfig().isEnabled(SPConfig::OutOfProcess)) {
         SAMLConfig& conf = SAMLConfig::getConfig();
 
@@ -244,12 +250,12 @@ void SAML2Logout::receive(DDF& in, ostream& out)
     }
 
     // Unpack the request.
-    scoped_ptr<HTTPRequest> req(getRequest(in));
+    scoped_ptr<HTTPRequest> req(getRequest(*app, in));
 
     // Wrap a response shim.
     DDF ret(nullptr);
     DDFJanitor jout(ret);
-    scoped_ptr<HTTPResponse> resp(getResponse(ret));
+    scoped_ptr<HTTPResponse> resp(getResponse(*app, ret));
 
     // Since we're remoted, the result should either be a throw, which we pass on,
     // a false/0 return, which we just return as an empty structure, or a response/redirect,
@@ -357,12 +363,14 @@ pair<bool,long> SAML2Logout::doRequest(const Application& application, HTTPReque
 
     // Create the policy.
     scoped_ptr<SecurityPolicy> policy(
-        application.getServiceProvider().getSecurityPolicyProvider()->createSecurityPolicy(application, &IDPSSODescriptor::ELEMENT_QNAME, policyId.second)
+        application.getServiceProvider().getSecurityPolicyProvider()->createSecurityPolicy(
+            samlconstants::SAML20_PROFILE_SSO_LOGOUT, application, &IDPSSODescriptor::ELEMENT_QNAME, policyId.second
+            )
         );
 
     // Decode the message.
     string relayState;
-    scoped_ptr<XMLObject> msg(m_decoder->decode(relayState, request, *policy));
+    scoped_ptr<XMLObject> msg(m_decoder->decode(relayState, request, &response, *policy));
     const LogoutRequest* logoutRequest = dynamic_cast<LogoutRequest*>(msg.get());
     if (logoutRequest) {
         if (!policy->isAuthenticated())
@@ -492,7 +500,7 @@ pair<bool,long> SAML2Logout::doRequest(const Application& application, HTTPReque
         }
 
         if (m_decoder->isUserAgentPresent()) {
-            if (!session_id.empty()) {
+            if (!session_id.empty() || m_notifyWithoutSession) {
                 // Pass control to the first front channel notification point, if any.
                 map<string,string> parammap;
                 if (!relayState.empty())
