@@ -38,6 +38,7 @@
 #include <xercesc/util/XMLStringTokenizer.hpp>
 #include <xmltooling/XMLToolingConfig.h>
 #include <xmltooling/util/NDC.h>
+#include <xmltooling/util/XMLConstants.h>
 #include <xmltooling/util/XMLHelper.h>
 
 #ifndef SHIBSP_LITE
@@ -863,6 +864,7 @@ void XMLApplication::doSSO(const ProtocolProvider& pp, set<string>& protocols, D
         );
     m_handlers.push_back(chain);
     m_sessionInitDefault = chain.get();
+    m_sessionInitMap["Login"] = chain.get();
     m_handlerMap["/Login"] = chain.get();
 }
 
@@ -1529,6 +1531,15 @@ void XMLApplication::limitRedirect(const GenericRequest& request, const char* ur
     if (m_redirectLimit == REDIRECT_LIMIT_INHERIT)
         return m_base->limitRedirect(request, url);
     if (m_redirectLimit != REDIRECT_LIMIT_NONE) {
+
+        // This is ugly, but the purpose is to prevent blocking legitimate redirects
+        // that lack a trailing slash after the hostname. If there are fewer than 3
+        // slashes, we assume the hostname wasn't terminated.
+        string urlcopy(url);
+        if (count(urlcopy.begin(), urlcopy.end(), '/') < 3) {
+            urlcopy += '/';
+        }
+
         vector<string> whitelist;
         if (m_redirectLimit == REDIRECT_LIMIT_EXACT || m_redirectLimit == REDIRECT_LIMIT_EXACT_WHITELIST) {
             // Scheme and hostname have to match.
@@ -1547,7 +1558,7 @@ void XMLApplication::limitRedirect(const GenericRequest& request, const char* ur
 
         if (!whitelist.empty()) {
             for (vector<string>::const_iterator i = whitelist.begin(); i != whitelist.end(); ++i) {
-                if (XMLString::startsWithI(url, i->c_str())) {
+                if (istarts_with(urlcopy, *i)) {
                     return;
                 }
             }
@@ -1555,11 +1566,12 @@ void XMLApplication::limitRedirect(const GenericRequest& request, const char* ur
 
         if (!m_redirectWhitelist.empty()) {
             for (vector<string>::const_iterator i = m_redirectWhitelist.begin(); i != m_redirectWhitelist.end(); ++i) {
-                if (XMLString::startsWithI(url, i->c_str())) {
+                if (istarts_with(urlcopy, *i)) {
                     return;
                 }
             }
         }
+
         Category::getInstance(SHIBSP_LOGCAT ".Application").warn("redirectLimit policy enforced, blocked redirect to (%s)", url);
         throw opensaml::SecurityPolicyException("Blocked unacceptable redirect location.");
     }
